@@ -1,10 +1,10 @@
 # Oxford University calendar conversion.
 # Simon Cozens (c) 1999-2002
 # Eugene van der Pijll (c) 2004
-# Dominic Hargreaves / University of Oxford (c) 2007-2013
+# Dominic Hargreaves / University of Oxford (c) 2007-2015
 # Artistic License
 package Oxford::Calendar;
-$Oxford::Calendar::VERSION = "2.09";
+$Oxford::Calendar::VERSION = "2.10";
 use strict;
 use Text::Abbrev;
 use Date::Calc qw(Add_Delta_Days Decode_Date_EU Delta_Days Mktime Easter_Sunday Date_to_Days Day_of_Week_to_Text Day_of_Week);
@@ -63,13 +63,13 @@ F</etc/oxford-calendar.yaml>; if this file does not exist, built-in data
 will be used. The built-in data is periodically updated from the
 semi-authoritative source at
 
-L<http://www.ox.ac.uk/about_the_university/university_year/dates_of_term.html>.
+L<http://www.ox.ac.uk/about/facts-and-figures/dates-of-term>.
 
 or the authoritative source, the Gazette, available online from
 
 L<http://www.ox.ac.uk/gazette/>.
 
-L<http://www.ox.ac.uk/about_the_university/university_year/index.html>
+L<http://www.ox.ac.uk/news-and-events/The-University-Year>
 describes the academic year at Oxford.
 
 =head1 DATE FORMAT
@@ -623,7 +623,6 @@ Calendar:
     start: 17/01/2016
   Hilary 2017:
     start: 15/01/2017
-    provisional: 1
   Hilary 2018:
     start: 14/01/2018
     provisional: 1
@@ -633,6 +632,9 @@ Calendar:
   Hilary 2020:
     start: 19/01/2020
     provisional: 1
+  Hilary 2021:
+    start: 17/01/2021
+    provisional: 1
   Michaelmas 2001:
     start: 07/10/2001
   Michaelmas 2002:
@@ -665,7 +667,6 @@ Calendar:
     start: 11/10/2015
   Michaelmas 2016:
     start: 09/10/2016
-    provisional: 1
   Michaelmas 2017:
     start: 08/10/2017
     provisional: 1
@@ -675,6 +676,9 @@ Calendar:
   Michaelmas 2019:
     start: 13/10/2019
     provisional: 1
+  Michaelmas 2020:
+    start: 11/10/2020
+    provisional: 1
   Trinity 2001:
     start: 22/04/2001
   Trinity 2002:
@@ -709,7 +713,6 @@ Calendar:
     start: 24/04/2016
   Trinity 2017:
     start: 23/04/2017
-    provisional: 1
   Trinity 2018:
     start: 22/04/2018
     provisional: 1
@@ -719,3 +722,6 @@ Calendar:
   Trinity 2020:
     start: 26/04/2020
     provisional: 1
+  Trinity 2021:
+    start: 25/04/2021
+    provisional: 1
